==> magento-magento-cloud-docker-1.2.1.zip: src/Compose/ProductionBuilder/Service/Blackfire.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Magento\CloudDocker\Compose\ProductionBuilder\Service;

use Magento\CloudDocker\Compose\BuilderInterface;
use Magento\CloudDocker\Compose\ProductionBuilder\ServiceBuilderInterface;
use Magento\CloudDocker\Config\Config;
use Magento\CloudDocker\Service\ServiceFactory;
use Magento\CloudDocker\Service\ServiceInterface;

/**
 * Returns Blackfire service configuration
 */
class Blackfire implements ServiceBuilderInterface
{
    /**
     * @var ServiceFactory
     */
    private $serviceFactory;

    /**
     * @param ServiceFactory $serviceFactory
     */
    public function __construct(ServiceFactory $serviceFactory)
    {
        $this->serviceFactory = $serviceFactory;
    }

    /**
     * @inheritDoc
     */
    public function getName(): string
    {
        return ServiceInterface::SERVICE_BLACKFIRE;
    }

    /**
     * @inheritDoc
     */
    public function getServiceName(): string
    {
        return $this->getName();
    }

    /**
     * @inheritDoc
     */
    public function getConfig(Config $config): array
    {
        return $this->serviceFactory->create(
            $this->getServiceName(),
            $config->getServiceVersion($this->getServiceName()),
            [
                'environment' => [
                    'BLACKFIRE_SERVER_ID' => $config->getBlackfireConfig()['server_id'],
                    'BLACKFIRE_SERVER_TOKEN' => $config->getBlackfireConfig()['server_token'],
                    'BLACKFIRE_CLIENT_ID' => $config->getBlackfireConfig()['client_id'],
                    'BLACKFIRE_CLIENT_TOKEN' => $config->getBlackfireConfig()['client_token']
                ],
                'ports' => ["8707"]
            ],
            $config->getServiceImage($this->getServiceName())
        );
    }

    /**
     * @inheritDoc
     */
    public function getNetworks(): array
    {
        return [BuilderInterface::NETWORK_MAGENTO];
    }

    /**
     * @inheritDoc
     */
    public function getDependsOn(Config $config): array
    {
        return [];
    }
}

==> magento-magento-cloud-docker-1.3.6.zip: src/Compose/ProductionBuilder/Service/Blackfire.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Magento\CloudDocker\Compose\ProductionBuilder\Service;

use Magento\CloudDocker\Compose\BuilderInterface;
use Magento\CloudDocker\Compose\ProductionBuilder\ServiceBuilderInterface;
use Magento\CloudDocker\Config\Config;
use Magento\CloudDocker\Service\ServiceFactory;
use Magento\CloudDocker\Service\ServiceInterface;

/**
 * Returns Blackfire service configuration
 */
class Blackfire implements ServiceBuilderInterface
{
    /**
     * @var ServiceFactory
     */
    private $serviceFactory;

    /**
     * @param ServiceFactory $serviceFactory
     */
    public function __construct(ServiceFactory $serviceFactory)
    {
        $this->serviceFactory = $serviceFactory;
    }

    /**
     * @inheritDoc
     */
    public function getName(): string
    {
        return ServiceInterface::SERVICE_BLACKFIRE;
    }

    /**
     * @inheritDoc
     */
    public function getServiceName(): string
    {
        return $this->getName();
    }

    /**
     * @inheritDoc
     */
    public function getConfig(Config $config): array
    {
        return $this->serviceFactory->create(
            $this->getServiceName(),
            $config->getServiceVersion($this->getServiceName()),
            [
                'environment' => [
                    'BLACKFIRE_SERVER_ID' => $config->getBlackfireConfig()['server_id'],
                    'BLACKFIRE_SERVER_TOKEN' => $config->getBlackfireConfig()['server_token'],
                    'BLACKFIRE_CLIENT_ID' => $config->getBlackfireConfig()['client_id'],
                    'BLACKFIRE_CLIENT_TOKEN' => $config->getBlackfireConfig()['client_token']
                ],
                'ports' => ["8707"]
            ],
            $config->getServiceImage($this->getServiceName()),
            $config->getCustomRegistry()
        );
    }

    /**
     * @inheritDoc
     */
    public function getNetworks(): array
    {
        return [BuilderInterface::NETWORK_MAGENTO];
    }

    /**
     * @inheritDoc
     */
    public function getDependsOn(Config $config): array
    {
        return [];
    }
}
